
-------------------------------------------------------------------------------
-- Optimzation
-------------------------------------------------------------------------------

-- GLOBALS: IsAddOnLoaded, InterfaceOptionsFrame_OpenToCategory, next, table, type

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(select(2, ...)) -- AddOn, Border, Constants, Database
local M = A:NewModule("Core Console", "AceConsole-3.0")

local commands, commandList = {}, {}

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnInitialize()
	self:AddCommand("?", function (...) M:Command_Help(...) end)
	self:AddCommand("conf", function (...) M:Command_Config(...) end)
	self:AddCommand("config", function (...) M:Command_Config(...) end, "open SixUI's interface options.")
	self:AddCommand("help", function (...) M:Command_Help(...) end)
	self:AddCommand("opt", function (...) M:Command_Config(...) end)
	self:AddCommand("options", function (...) M:Command_Config(...) end)
	self:AddCommand("v", function (...) M:Command_Version(...) end)
	self:AddCommand("ver", function (...) M:Command_Version(...) end)
	self:AddCommand("version", function (...) M:Command_Version(...) end, "show the SixUI version number.")
	self:RegisterChatCommand(C.COMMAND, "Command")
end

function M:AddCommand(command, callback, usage)
	if type(command) == "string" and type(callback) == "function" and (type(usage) == "string" or type(usage) == "nil") then
		commands[command] = {callback = callback, usage = usage}
		table.insert(commandList, command)
	end
end

function A:AddCommand(...)
	M:AddCommand(...)
end

function M:Command(string)
	local name, argument = self:GetArgs(string, 2)

	if not name or name == "" then
		self:Command_Config()
		return
	end

	if not commands[name] then
		A.PrintF("The command '%s' wasn't recognised.", A.Highlight(name))
		return
	end

	commands[name].callback(argument)
end

function M:Command_Config()
	if not IsAddOnLoaded("SixUI_Config") then
		A.PrintF("The AddOn '%s' isn't loaded.", A.Highlight("SixUI Config"))
		return
	end

	InterfaceOptionsFrame_OpenToCategory("SixUI")
	InterfaceOptionsFrame_OpenToCategory("SixUI")
end

function M:Command_Help()
	A.Print("SixUI help:")

	for _, name in next, commandList do
		if commands[name].usage then
			A.PrintF("- '%s' to %s", A.Highlight(name), commands[name].usage)
		end
	end
end

function M:Command_Version(argument)
	A.PrintF("SixUI version: %s", C.VERSION)
end
